@@ -79,7 +79,7 @@ class Dvol(ConfigDict):
     STATUS = ( "UNKNOWN", "UNSYNCED", "CREATING", "STARTING", "RUNNING", "TEST_FAILOVER", "FAILOVER", "MIGRATING", "MIGRATED", "FAILING_BACK_STOPPING_OLD_MASTER", "CREATE_FAILED", "TEST_FAILOVER_FAILED", "FAILOVER_FAILED", "RESIZING", "DELETING", "STOPPING", "STOPPED", "ERROR" )
 
     # Site type (CLC, ...)
-    PG_SITE_TYPE = ( "MANUAL", "VMWARE", "CLC", "AWS", "AZURE" )
+    PG_SITE_TYPE = ( "MANUAL", "VMWARE", "CLC", "AWS", "AZURE", "GOOGLE" )
 
     # Supported Dvol types (COW/COW, ROW/COW)
     TYPE = ( "COW", "ROW", "INVALID" )
@@ -737,7 +737,7 @@ class DvolCreate(namedtuple('DvolCreate', [
     @property
     def is_data_dvol(self):
         """Return True if configured as a Data Dvol"""
-        return self.pg_prim_type == 'MANUAL' # FIXME: site_type ( "MANUAL", "VMWARE", "CLC", "AWS", "AZURE" )
+        return self.pg_prim_type == 'MANUAL' # FIXME: site_type ( "MANUAL", "VMWARE", "CLC", "AWS", "AZURE", "GOOGLE" )
 
     @property
     def vg_name(self):
