@@ -4,18 +4,19 @@
 #
 # Usage: $0 [SRN-IP]
 #
+from __future__ import print_function, absolute_import, unicode_literals, division
 import sys
 from dgpy.cms_client import CmsClient
 
 # The disk-list call requires an SRN IP. Default to all SRNs if no IP given.
 client = CmsClient()
 for srn_ip in sys.argv[1:] if len(sys.argv) > 1 else client.srns:
-    print "\nDisks on {}:\n".format(srn_ip)
+    print("\nDisks on {}:\n".format(srn_ip))
     result = client.disk_list(srn_ip)
 
     cols = ("Device", "Size", "In Use By (target or pool)")
-    print "{0:^10} | {1:>5} | {2}".format(*cols)
-    print "{0:^10} | {1:>5} | {2}".format(*('-' * len(c) for c in cols))
+    print("{0:^10} | {1:>5} | {2}".format(*cols))
+    print("{0:^10} | {1:>5} | {2}".format(*('-' * len(c) for c in cols)))
     for d in sorted(result.disks.keys()):
         inUse = ""
         if result.disks[d].is_claimed:
@@ -25,5 +26,5 @@ for srn_ip in sys.argv[1:] if len(sys.argv) > 1 else client.srns:
                 inUse = "ERROR: unknown pool %r" % result.disks[d].vg_name
             else:
                 inUse = "{0} (available: {1:.1f}G)".format(result.disks[d].vg_name,
-                                                           result.pools[result.disks[d].vg_name]/(1024.**3))
-        print "{0:<10} | {1:4d}G | {2}".format(d, result.disks[d].size>>30, inUse)
+                                                           result.pools[result.disks[d].vg_name] / (1024**3))
+        print("{0:<10} | {1:4d}G | {2}".format(d, result.disks[d].size>>30, inUse))
