@@ -2,11 +2,12 @@
 #
 # Add a new peer into the peer list of a given SRN.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
 from dgpy.job        import status_printer
-from dgpy.errors     import LegacyMessageError, GrpcError, NotFoundError, TimeOutError
+from dgpy.errors     import LegacyMessageError, GrpcError, TimeOutError
 
 parser = argparse.ArgumentParser(description="Register replication nodes @IP1 and @IP2 as mutual peers")
 
@@ -25,7 +26,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Peer registration Job ID: {}".format(res.job_id)
+        print("Peer registration Job ID: {}".format(res.job_id))
 except (LegacyMessageError, GrpcError) as e:
     die("Failed to add {1} into the peer list of {0}: {2}".format(args.IP1, args.IP2, e))
 except TimeOutError as e:
