@@ -3,11 +3,11 @@
 # Create a non-legacy PG from a .yaml or .json input file.
 #
 # There are too many parameters for a command-line application.
-import os
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client      import CmsClient
 from dgpy.aggregates.dvol import dvol_pb2
-from dgpy.utils           import die, fatal, load_protobuf
+from dgpy.utils           import die, load_protobuf
 from dgpy.job             import status_printer
 from dgpy.errors          import GrpcError, NotFoundError, TimeOutError
 
@@ -25,7 +25,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Create {0.name} Job ID: {1}".format(req, res.job_id)
+        print("Create {0.name} Job ID: {1}".format(req, res.job_id))
 except NotFoundError as e:
     die("No such PG: '{0}'".format(args.PG))
 except GrpcError as e:
