@@ -3,6 +3,7 @@
 # Delete a non-legacy Protection Group  by name.
 #
 # Will throw an error if attempting to delete a legacy PG.
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
@@ -22,7 +23,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "PG deletion Job ID: {}".format(res.job_id)
+        print("PG deletion Job ID: {}".format(res.job_id))
 except NotFoundError as e:
     die("No such PG: '{0}'".format(args.PG))
 except GrpcError as e:
