@@ -2,6 +2,7 @@
 #
 # Migrate a non-legacy PG from a .yaml or .json input file.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import os
 import sys
 from dgpy.cms_client      import CmsClient
@@ -18,6 +19,6 @@ else:
         req = load_protobuf(sys.argv[1], dvol_pb2.PgMigrateRequest())
         res = CmsClient().pg_migrate(req)
     except GrpcError as e:
-        print "Failed to migrate {0.name}: {1}".format(req, e)
+        print("Failed to migrate {0.name}: {1}".format(req, e))
     else:
-        print "Migrate {0.name} Job ID: {1}".format(req, res.job_id)
+        print("Migrate {0.name} Job ID: {1}".format(req, res.job_id))
