@@ -4,9 +4,9 @@
 #
 # Usage: $0 [PG-Name]
 # If no PG-Name is present, list the PLUNs of all targets of all known PGs.
+from __future__ import print_function, absolute_import, unicode_literals
 import re
 import sys
-import time
 from dgpy.cms_client import CmsClient
 
 cols = ("VM Name", "Lun#", "Name", "Size")
@@ -15,9 +15,9 @@ client = CmsClient()
 for pg in (sys.argv[1],) if len (sys.argv) > 1 else client.dvols:
     pluns = client.dvol_list_pluns(pg)
     if pluns:
-        print "\n{} Disks:".format(pg)
-        print "| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(*cols)
-        print "| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(*('-' * len(c) for c in cols))
+        print("\n{} Disks:".format(pg))
+        print("| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(*cols))
+        print("| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(*('-' * len(c) for c in cols)))
         for plun in pluns:
             fields = plun.split('\t')
             #
@@ -31,6 +31,6 @@ for pg in (sys.argv[1],) if len (sys.argv) > 1 else client.dvols:
             # Newer-style Protection Groups report their size in bytes as a string (e.g. "10240")
             if re.match(r'^\d+$', size):
                 size = "{0:d}G".format(int(size)>>30)
-            print "| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(vm, lun, name, size)
+            print("| {0:^20} | {1:^5} | {2:^8} | {3:>6} |".format(vm, lun, name, size))
     else:
-        print "\n{0} Disks: {1!r}".format(pg, pluns)
+        print("\n{0} Disks: {1!r}".format(pg, pluns))
