@@ -10,16 +10,17 @@
 #         - @tenant_id:  Tenant ID of the Azure Active Directory
 #         - @region:     Azure region to use for this site
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import sys
 from dgpy.cms_client import CmsClient
 from dgpy.errors     import GrpcError
 
 if len(sys.argv) != 7:
-    print >>sys.stderr, "Usage: %s <site-name> <client_id> <secret> <sub_id> <tenant_id> <region>" % sys.argv[0]
+    print("Usage: %s <site-name> <client_id> <secret> <sub_id> <tenant_id> <region>" % sys.argv[0], file=sys.stderr)
 else:
     try:
         res = CmsClient().site_update_azure(*sys.argv[1:])
     except GrpcError as e:
-        print "Failed to add Azure site {0}: {1}".format(sys.argv[1], e)
+        print("Failed to add Azure site {0}: {1}".format(sys.argv[1], e))
     else:
-        print "Adding Azure site {0} Job ID: {1}".format(sys.argv[1], res.job_id)
+        print("Adding Azure site {0} Job ID: {1}".format(sys.argv[1], res.job_id))
