@@ -5,6 +5,7 @@
 # Usage: $0 <PG-Name> <IQN>, with
 #         - @PG-Name: name of the protection group hosting the target
 #         - @IQN:     iSCSI IQN of the target to remove
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
@@ -25,7 +26,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Target delete job #{0}".format(res.job_id)
+        print("Target delete job #{0}".format(res.job_id))
 except (LegacyMessageError, GrpcError) as e:
     die("Failed to delete {0} target: {1}".format(args.DVOL, e))
 except TimeOutError as e:
