@@ -2,11 +2,12 @@
 #
 # Set the login password for a given user.
 #
+from __future__ import print_function, absolute_import, unicode_literals
 import argparse
 from dgpy.cms_client import CmsClient
 from dgpy.utils      import die
 from dgpy.job        import status_printer
-from dgpy.errors     import LegacyMessageError, GrpcError, NotFoundError, TimeOutError
+from dgpy.errors     import LegacyMessageError, GrpcError, TimeOutError
 
 parser = argparse.ArgumentParser(description="Set the login password of @USER to @PASS")
 
@@ -23,7 +24,7 @@ try:
     if args.wait or args.timeout > 0:
         client.wait_for_job(res.job_id, args.timeout, status_printer)
     else:
-        print "Set {0} password Job ID: {1}".format(args.USER, res.job_id)
+        print("Set {0} password Job ID: {1}".format(args.USER, res.job_id))
 except (LegacyMessageError, GrpcError) as e:
     die("Failed to set password for {0}: {1}".format(args.USER, e))
 except TimeOutError as e:
