@@ -1,34 +1,34 @@
 #
 # Helper functions
 #
-import re
-import os
-import sys
-import time
-import yaml
-import json
-import string
+from __future__ import absolute_import, unicode_literals, division, print_function, division
 
-import pwd
-import spwd
-import crypt
-import struct
-import socket
-import smtplib
-import logging
-import operator
 import collections
+import configparser
+import crypt
+import io
+import logging
+import math
+import operator
+import os
+import pwd
+import re
+import smtplib
+import socket
+import spwd
+import struct
 import subprocess
-import ConfigParser
+import sys
+from itertools import tee, groupby
 
-from itertools       import islice, imap, starmap, tee, groupby, ifilter, ifilterfalse
-from cStringIO       import StringIO
+import yaml
 from google.protobuf import json_format
 
+
 #-----------------------------------------------------------------------------------------------
 # Files, I/O, Logging
 #-----------------------------------------------------------------------------------------------
-def init_logging(default_level=logging.INFO, handlers=[], show_time=True):
+def init_logging(default_level=logging.INFO, handlers=None, show_time=True):
     """Sets up root logger by adding a console handler.
     @default_level: default console logging level (use logging.DEBUG for highest verbosity)
     @handlers:      additional handlers to register (optional)
@@ -45,7 +45,7 @@ def init_logging(default_level=logging.INFO, handlers=[], show_time=True):
 
         console_fmt = "%(name)-15s  %(levelname)-7s %(message)s"
         if show_time:
-                console_fmt = "%(asctime)s " + console_fmt
+            console_fmt = "%(asctime)s " + console_fmt
         console.setFormatter(logging.Formatter(console_fmt))
 
         # Events to be filtered out on the console
@@ -53,14 +53,14 @@ def init_logging(default_level=logging.INFO, handlers=[], show_time=True):
 
     # This function should be idempotent.
     # It relies on addHandler to not add the same handler twice.
-    for handler in handlers:
+    for handler in handlers or []:
         root.addHandler(handler)
     return root
 
 
 def die(msg):
     """Pretend that Python is Perl."""
-    print >>sys.stderr, msg.rstrip()
+    print(msg.rstrip(), file=sys.stderr)
     sys.exit(-1)
 
 def fatal(msg):
@@ -68,7 +68,7 @@ def fatal(msg):
 
 def load_protobuf(filename, message):
     """Parses JSON|YAML data contained in @file into the protobuf @message."""
-    with open(filename) as f:
+    with io.open(filename, 'rt') as f:
         data = f.read()
         if filename.endswith('.yaml'):
             return json_format.ParseDict(yaml.safe_load(data), message)
@@ -76,44 +76,13 @@ def load_protobuf(filename, message):
             return json_format.Parse(data, message)
         die("File name must end either in .json or .yaml (not: '{}').".format(filename))
 
-def get_input(prompt, default=None, type=None, valfnc=None, choices=None):
-    """Get user input from stdin. Silently continue prompting if
-    - type is present and type conversion threw an exception,
-    - valfnc returns negative result,
-    - choices are present and response did not match choices.
-    @prompt:  prompt string to ask
-    @default: default value to return in case no value was entered
-    @type:    one-argument conversion function (optional, e.g. str, int, ...)
-    @valfnc:  validation function (optional)
-    @choices: array of permissible choices (optional)
-    """
-    if not os.isatty(sys.stdin.fileno()):
-        fatal("stdin is not from a terminal - aborting.")
-    if default is not None and default != '':
-        prompt += ' [%s]' % default
-    while True:
-        try:
-            resp = raw_input(prompt + ': ').strip()
-        except (EOFError, KeyboardInterrupt):
-            die("... exiting")
-        if resp:
-            try:
-                if type:
-                    resp = type(resp)
-                if (not valfnc or bool(valfnc(resp))) and (not choices or resp in choices):
-                    return resp
-            except Exception as e:
-                pass
-        elif default is not None:
-            return default
-
 def parse_key_value_from_fo(fo, allow_whitespace_in_values=False):
     """Read (Syntropy) key/value configuration from file object @fo
     @fo:                          file object to use
     @allow_white_space_in_values: generate error on leading/trailing whitespace in values
     and return a dictionary of mappings.
     """
-    config = ConfigParser.RawConfigParser()
+    config = configparser.RawConfigParser()
     # Preserve case of configuration keys, see
     # http://stackoverflow.com/questions/19359556/configparser-reads-capital-keys-and-make-them-lower-case
     config.optionxform = str
@@ -126,15 +95,15 @@ def parse_key_value_from_fo(fo, allow_whitespace_in_values=False):
     fo.close()
 
     # Strip comments up to end of line.
-    ini_fp = StringIO(re.sub('[#;].*$', '', ini_str, flags=re.MULTILINE))
-    config.readfp(ini_fp)
+    ini_fp = io.StringIO(re.sub('[#;].*$', '', ini_str, flags=re.MULTILINE))
+    config.read_file(ini_fp)
 
     conf = { k:v.strip('"') for k,v in config.items(FAKE_SECTION) }
     if not conf:
         raise LookupError("empty configuration - no items.")
     elif not allow_whitespace_in_values:
-        for k,v in conf.iteritems():
-            if re.search('(^\s+|\s+$)', v):
+        for k,v in conf.items():
+            if re.search(r'(^\s+|\s+$)', v):
                 raise ValueError("whitespace in configuration: %s = %r" % (k, v))
     return conf
 
@@ -142,7 +111,7 @@ def TokenizeFile(filename):
     """Split a file into a list of lines. Discards comments starting with '#'.
     Strips leading/trailing whitespace and ignores empty lines.
     """
-    return filter(bool, (re.sub('#.*$', '', l).strip() for l in open(filename)))
+    return [line for line in (re.sub('#.*$', '', l).strip() for l in io.open(filename, 'rt')) if line]
 
 def first_file_by_stat_key(file_list, stat_fn=os.stat, key='st_mtime'):
     """Order elements in @file_list according to stat-result @key, and return first element.
@@ -150,8 +119,9 @@ def first_file_by_stat_key(file_list, stat_fn=os.stat, key='st_mtime'):
     @stat_fn:   function to call for obtaining stat results
     @key:       key name (must be one of the attributes in posix.stat_result)
     """
-    if file_list:
-        return sorted(file_list, key=lambda f: getattr(stat_fn(f), key), reverse=True)[0]
+    if not file_list:
+        return None
+    return sorted(file_list, key=lambda f: getattr(stat_fn(f), key), reverse=True)[0]
 
 #-----------------------------------------------------------------------------------------------
 # General System Administration
@@ -166,7 +136,7 @@ def run_cmd(command, stdin=None, wait=True, **kwargs):
     Returns (exit_code, stdout, stderr) if wait=False, else a Popen object.
     """
     process = subprocess.Popen(args      = command,
-                               shell     = isinstance(command, basestring),
+                               shell     = isinstance(command, str),
                                close_fds = True,
                                stdin     = subprocess.PIPE,
                                stdout    = subprocess.PIPE,
@@ -190,7 +160,7 @@ def system(command, stdin=None):
             logging.warning(stderr)
         return rc == 0
     except Exception:
-        logging.exception("Command '%r' failed" % command)
+        logging.exception("Command {0:r} failed".format(command))
 
 
 def get_current_user():
@@ -228,10 +198,10 @@ def check_system_password(user, passwd):
         sys_pass = pw.pw_passwd
     return crypt.crypt(passwd, sys_pass) == sys_pass
 
-def human_time(sec):
+def human_time(sec):  # pylint: disable=too-many-return-statements
     """Format @sec as a human-readable time string."""
     seconds = abs(int(sec))
-    d, h, m = seconds / 86400, (seconds % 86400) / 3600, (seconds % 3600) / 60
+    d, h, m = seconds // 86400, (seconds % 86400) // 3600, (seconds % 3600) // 60
     if d:
         if h:
             return '%ud %uh' % (d, h)
@@ -242,7 +212,7 @@ def human_time(sec):
         return '%u:%02uh' % (h, m)
     elif m:
         return '%u:%02um' % (m, seconds % 60)
-    elif type(sec) is float:
+    elif isinstance(sec, float):
         return '%.2g sec' % sec
     else:
         return "%d sec" % seconds
@@ -250,6 +220,7 @@ def human_time(sec):
 def lvm_size(str_or_number):
     """Convert a LVM size string/number into the corresponding integral number of bytes.
     For example: 10M -> 10485760, 10GB -> 10737418240
+    Fractional values are rounded up to the next-higher integer value.
     """
     p = re.compile(r'^(\d+(?:\.\d+)?)\s*(K|KB|M|MB|G|GB|T|TB|B)?$', re.IGNORECASE)
     m = p.match(str(str_or_number))
@@ -271,7 +242,7 @@ def lvm_size(str_or_number):
             size *= 1024**4
         else:
             raise TypeError("Invalid LVM suffix %r" % m.group(2))
-    return int(round(size))
+    return int(math.ceil(size))
 
 def to_lvm_size(number_of_bytes, fmt="%.1f"):
     """Inverse of lvm_size() using numeric string format @fmt."""
@@ -287,7 +258,7 @@ def to_lvm_size(number_of_bytes, fmt="%.1f"):
 def avg(generator_expression):
     """Return the average of the numbers listed in @generator_expression."""
     l = list(generator_expression)
-    return sum(l)/len(l) if l else 0
+    return sum(l) / len(l) if l else 0
 
 #-----------------------------------------------------------------------------------------------
 # Networking
@@ -296,19 +267,18 @@ def get_bound_local_ports_from_fd(fd):
     """Return (listen-IP, port) set of bound TCP/UDPv4 ports. See proc(5).
     @fd: open file descriptor pointing to /proc/net/tcp or /proc/net/udp.
     """
-    return set(imap(lambda e: (socket.inet_ntoa(struct.pack("<I", int(e[0], 16))), int(e[1], 16)),
-               re.findall('^\s*\d+:\s*([\dA-F]{8}(?:[\dA-F]{24})?):([\dA-F]{4})\s',
-                          fd.read(), re.MULTILINE)))
+    return set((socket.inet_ntoa(struct.pack("<I", int(e[0], 16))), int(e[1], 16))
+               for e in re.findall(r'^\s*\d+:\s*([\dA-F]{8}(?:[\dA-F]{24})?):([\dA-F]{4})\s', fd.read(), re.MULTILINE))
 
 def is_valid_ip(ips):
     """Test whether @ips is a valid IPv4 string"""
-    return re.match('(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$', ips)
+    return re.match(r'(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$', ips)
 
 def is_private_ip(ips):
     """Primitive check to see if @ips is a private IP address (as specified in RFC 1918)."""
-    return re.match('^10\.\d{1,3}\.\d{1,3}.\d{1,3}$', ips) or \
-           re.match('^192\.168\.\d{123}\.\d{1,3}$', ips)   or \
-           re.match('^172.(1[6-9]|2\d|3[0-1])\.\d{1,3}\.\d{1,3}$', ips)
+    return re.match(r'^10\.\d{1,3}\.\d{1,3}.\d{1,3}$', ips) or \
+           re.match(r'^192\.168\.\d{123}\.\d{1,3}$', ips)   or \
+           re.match(r'^172.(1[6-9]|2\d|3[0-1])\.\d{1,3}\.\d{1,3}$', ips)
 
 def is_valid_dns_name(hostname):
     """Check if @hostname is a valid DNS name, according to RFCs 952 and 1123:
@@ -321,12 +291,12 @@ def is_valid_dns_name(hostname):
     if len(hostname) <= 255:
         if hostname.endswith("."):   # A single trailing dot is legal
             hostname = hostname[:-1] # strip exactly one dot from the right, if present
-        allowed = re.compile("(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
+        allowed = re.compile(r"(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
         return all(allowed.match(x) for x in hostname.split("."))
 
 def is_valid_port_number(port):
     """Return True if @port evaluates to a number in the range 1..2^16-1"""
-    prt = re.compile('\s*(6553[0-5]|655[0-2]\d|65[0-4](\d){2}|6[0-4](\d){3}|[1-5](\d){4}|[1-9](\d){0,3})\s*$')
+    prt = re.compile(r'\s*(6553[0-5]|655[0-2]\d|65[0-4](\d){2}|6[0-4](\d){3}|[1-5](\d){4}|[1-9](\d){0,3})\s*$')
     return prt.match(str(port))
 
 def find_first_open_port(bind_address='0.0.0.0', port=1024):
@@ -335,7 +305,7 @@ def find_first_open_port(bind_address='0.0.0.0', port=1024):
     @port:        port number to start at
     """
     assert port > 0
-    with open('/proc/net/tcp') as proc_net_tcp:
+    with io.open('/proc/net/tcp', 'rt') as proc_net_tcp:
         bound = get_bound_local_ports_from_fd(proc_net_tcp)
 
     # Maximum port number is 2^16-1, as TCP uses 2-byte port numbers.
@@ -356,10 +326,10 @@ def send_email(subject, body, sender='grenker@datagardens.com'):
     # Restrict the maximum body length. Some mailers limit at 1 or 2MB, others at 10,20 or 50MB.
     MAX_BODY_LEN = 1 * 1024**2
     if len(body) > MAX_BODY_LEN:
-        tmp = StringIO(body)
+        tmp = io.StringIO(body)
         tmp.seek(-MAX_BODY_LEN, 2)
         body = 'WARNING: original message truncated to %d MB due to excessive length (%.1f MB):\n\n' % (
-                MAX_BODY_LEN/1024**2, len(body)/1024**2)
+                MAX_BODY_LEN//1024**2, len(body)/1024**2)
         body += tmp.read()
         tmp.close()
     try:
@@ -370,7 +340,7 @@ def send_email(subject, body, sender='grenker@datagardens.com'):
                          'Subject: %s\n\n' \
                          '%s' % (sender, sender, subject, body))
     except Exception as e:
-        logging.critical('Failed to send email')
+        logging.critical('Failed to send email: {}'.format(e))
 
 #-----------------------------------------------------------------------------------------------
 # Python Extensions
@@ -379,7 +349,7 @@ def enum(*sequential, **named):
     """Create an enum in Python 2.x (in 3.x enums are a basic type).
     From http://stackoverflow.com/questions/36932/how-can-i-represent-an-enum-in-python
     """
-    enums = dict(zip(sequential, range(len(sequential))), **named)
+    enums = dict(zip(sequential, list(range(len(sequential)))), **named)
     return type('Enum', (), enums)
 
 def hasmethod(obj, method_name):
@@ -403,11 +373,11 @@ def subseq(seq, l):
         idx += l
 
 # 3.3 itertools function
-def accumulate(list, sum=0):
-    """Return cumulative sums of @list, starting at @sum."""
-    for el in list:
-        yield sum
-        sum += el
+def accumulate(l, sumval=0):
+    """Return cumulative sums of @l, starting at @sumval."""
+    for el in l:
+        yield sumval
+        sumval += el
 
 def flatten(it):
     """Generator function which turns nested iterable @it into a shallow sequence."""
@@ -439,7 +409,7 @@ def partition(seq, func=None):
     If @func is None, split according to which elements of @seq evaluate to True/False.
     """
     s1, s2 = tee(seq)
-    return ifilter(func, s1), ifilterfalse(func, s2)
+    return (e for e in s1 if func(e)), (e for e in s2 if not func(e))
 
 def field_map(dictseq, key_map):
     """Field mapping function from David Beazley's excellent series on generators
@@ -448,14 +418,14 @@ def field_map(dictseq, key_map):
     Produce sequence of dictionaries, with values for keys replaced by function results
     """
     for d in dictseq:
-        for key, func in key_map.iteritems():
+        for key, func in key_map.items():
             d[key] = func(d[key])
         yield d
 
 def invert_dictionary_with_duplicates(d):
     """Invert dictionary @d by generating a map (value, [list-of-keys for value])."""
     key, value = operator.itemgetter(0), operator.itemgetter(1)
-    return [ (v, map(key, g)) for v,g in groupby(sorted(d.iteritems(),
+    return [ (v, list(map(key, g))) for v,g in groupby(sorted(iter(d.items()),
                                                         key=value), value) ]
 
 def gen_grep(pat, lines):
@@ -470,13 +440,13 @@ def gen_upto_mark(it, pred):
     for el in it:
         yield el
         if pred(el):
-            it.close()		# Shut down input iterator
+            it.close()      # Shut down input iterator
 
 def gen_after_mark(it, pred):
     """Generate sequence elements from @it (strictly) after mark indicated by predicate @pred."""
     for el in it:
         if pred(el):
-           break
+            break
     return it
 
 def nfield(it, n=1):
